from .avito import AvitoManager
from .base import Platform
from .instagram import InstagramManager
from .ok import OkManager
from .tg import TgManager
from .ula import UlaManager
from .vk import VKManager
from .yam import YandexMarketManager

__all__ = (
    "AvitoManager",
    "InstagramManager",
    "OkManager",
    "TgManager",
    "UlaManager",
    "VKManager",
    "YandexMarketManager",
    "Platform",
)
